@@ -11,7 +11,7 @@ use Text::Wrap 'wrap';
 use Bible::OBML::HTML;
 use Bible::Reference 1.02;
 
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.09'; # VERSION
 
 with 'Throwable';
 
@@ -48,9 +48,6 @@ private_method _update_ref => sub {
     $self->_reference->acronyms( $self->acronyms );
 };
 
-binmode( STDOUT, ':encoding(utf8)' );
-binmode( STDERR, ':encoding(utf8)' );
-
 sub read_file {
     my ( $self, $filename ) = @_;
     open( my $file, '<:encoding(utf8)', $filename ) or $self->throw($!);
@@ -516,7 +513,7 @@ Bible::OBML - Open Bible Markup Language parser and renderer
 
 =head1 VERSION
 
-version 1.08
+version 1.09
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bible-OBML.svg)](https://travis-ci.org/gryphonshafer/Bible-OBML)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bible-OBML/badge.png)](https://coveralls.io/r/gryphonshafer/Bible-OBML)
